# Copyright 2021 Sean Robertson
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Utilities for (de)serializing Parameterized objects"""

from ._classic_serialization import (
    DefaultArrayDeserializer,
    DefaultArraySerializer,
    DefaultBooleanDeserializer,
    DefaultClassSelectorDeserializer,
    DefaultClassSelectorSerializer,
    DefaultDataFrameDeserializer,
    DefaultDataFrameSerializer,
    DefaultDateDeserializer,
    DefaultDateRangeDeserializer,
    DefaultDateRangeSerializer,
    DefaultDateSerializer,
    DefaultDeserializer,
    DefaultIntegerDeserializer,
    DefaultListDeserializer,
    DefaultListSelectorDeserializer,
    DefaultListSelectorSerializer,
    DefaultNumberDeserializer,
    DefaultNumericTupleDeserializer,
    DefaultObjectSelectorDeserializer,
    DefaultObjectSelectorSerializer,
    DefaultSerializer,
    DefaultSeriesSerializer,
    DefaultStringDeserializer,
    DefaultTupleSerializer,
    deserialize_from_dict,
    deserialize_from_ini,
    deserialize_from_json,
    deserialize_from_yaml,
    JsonStringArrayDeserializer,
    JsonStringArraySerializer,
    JsonStringDataFrameDeserializer,
    JsonStringDataFrameSerializer,
    JsonStringDateRangeDeserializer,
    JsonStringDateRangeSerializer,
    JsonStringDictDeserializer,
    JsonStringDictSerializer,
    JsonStringListDeserializer,
    JsonStringListSelectorDeserializer,
    JsonStringListSelectorSerializer,
    JsonStringListSerializer,
    JsonStringNumericTupleDeserializer,
    JsonStringSeriesDeserializer,
    JsonStringSeriesSerializer,
    JsonStringTupleDeserializer,
    JsonStringTupleSerializer,
    ParamConfigDeserializer,
    ParamConfigSerializer,
    ParamConfigTypeError,
    serialize_to_dict,
    serialize_to_ini,
    serialize_to_json,
    serialize_to_yaml,
)
from ._serializer import (
    JsonSerializable,
    RecklessJsonSerialization,
    RecklessSerializableSerialization,
    RecklessYamlSerialization,
    register_serializer,
    Serializable,
    SerializableSerialization,
    unregister_serializer,
    YamlSerializable,
    YamlSerialization,
)
from ._file_serialization import (
    deserialize_from_json_to_obj,
    deserialize_from_yaml_to_obj,
    serialize_from_obj_to_json,
    serialize_from_obj_to_yaml,
    yaml_is_available,
)

__all__ = [
    "DefaultArrayDeserializer",
    "DefaultArraySerializer",
    "DefaultBooleanDeserializer",
    "DefaultClassSelectorDeserializer",
    "DefaultClassSelectorSerializer",
    "DefaultDataFrameDeserializer",
    "DefaultDataFrameSerializer",
    "DefaultDateDeserializer",
    "DefaultDateRangeDeserializer",
    "DefaultDateRangeSerializer",
    "DefaultDateSerializer",
    "DefaultDeserializer",
    "DefaultIntegerDeserializer",
    "DefaultListDeserializer",
    "DefaultListSelectorDeserializer",
    "DefaultListSelectorSerializer",
    "DefaultNumberDeserializer",
    "DefaultNumericTupleDeserializer",
    "DefaultObjectSelectorDeserializer",
    "DefaultObjectSelectorSerializer",
    "DefaultSerializer",
    "DefaultSeriesSerializer",
    "DefaultStringDeserializer",
    "DefaultTupleSerializer",
    "deserialize_from_dict",
    "deserialize_from_ini",
    "deserialize_from_json_to_obj",
    "deserialize_from_json",
    "deserialize_from_yaml_to_obj",
    "deserialize_from_yaml",
    "JsonSerializable",
    "JsonStringArrayDeserializer",
    "JsonStringArraySerializer",
    "JsonStringDataFrameDeserializer",
    "JsonStringDataFrameSerializer",
    "JsonStringDateRangeDeserializer",
    "JsonStringDateRangeSerializer",
    "JsonStringDictDeserializer",
    "JsonStringDictSerializer",
    "JsonStringListDeserializer",
    "JsonStringListSelectorDeserializer",
    "JsonStringListSelectorSerializer",
    "JsonStringListSerializer",
    "JsonStringNumericTupleDeserializer",
    "JsonStringSeriesDeserializer",
    "JsonStringSeriesSerializer",
    "JsonStringTupleDeserializer",
    "JsonStringTupleSerializer",
    "ParamConfigDeserializer",
    "ParamConfigSerializer",
    "ParamConfigTypeError",
    "RecklessJsonSerialization",
    "RecklessSerializableSerialization",
    "RecklessYamlSerialization",
    "register_serializer",
    "Serializable",
    "SerializableSerialization",
    "serialize_from_obj_to_json",
    "serialize_from_obj_to_yaml",
    "serialize_to_dict",
    "serialize_to_ini",
    "serialize_to_json",
    "serialize_to_yaml",
    "unregister_serializer",
    "yaml_is_available",
    "YamlSerializable",
    "YamlSerialization",
]
